Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/mmr902_simpletest.py
    :caption: examples/mmr902_simpletest.py
    :lines: 5-

Operation mode settings
------------------------

Example showing the Operation mode setting

.. literalinclude:: ../examples/mmr902_operation_mode.py
    :caption: examples/mmr902_operation_mode.py
    :lines: 5-
